@@ -313,6 +313,40 @@ class TestUnidiffParser(unittest.TestCase):
         self.assertTrue(res[2].is_added_file)
         self.assertEqual(res[2].path, 'file3')
 
+    def test_parse_filename_with_spaces(self):
+        filename = os.path.join(self.samples_dir, 'samples/git_filenames_with_spaces.diff')
+        with open(filename) as f:
+            res = PatchSet(f)
+
+        self.assertEqual(len(res), 1)
+
+        self.assertEqual(res[0].source_file, '/dev/null')
+        self.assertEqual(res[0].target_file, 'b/has spaces/t.sql')
+        self.assertTrue(res[0].is_added_file)
+        self.assertEqual(res[0].path, 'has spaces/t.sql')
+
+    def test_parse_filename_prefix_with_spaces(self):
+        filename = os.path.join(self.samples_dir, 'samples/git_filenames_with_spaces_prefix.diff')
+        with open(filename) as f:
+            res = PatchSet(f)
+
+        self.assertEqual(len(res), 1)
+
+        self.assertEqual(res[0].source_file, '/dev/null')
+        self.assertEqual(res[0].target_file, 'dst://foo bar/baz')
+        self.assertTrue(res[0].is_added_file)
+        self.assertEqual(res[0].path, 'dst://foo bar/baz')
+
+    def test_deleted_file(self):
+        filename = os.path.join(self.samples_dir, 'samples/git_delete.diff')
+        with open(filename) as f:
+            res = PatchSet(f)
+
+        self.assertEqual(len(res), 1)
+        self.assertEqual(res[0].source_file, 'a/somefile.c')
+        self.assertEqual(res[0].target_file, '/dev/null')
+        self.assertTrue(res[0].is_removed_file)
+
     def test_diff_lines_linenos(self):
         with open(self.sample_file, 'rb') as diff_file:
             res = PatchSet(diff_file, encoding='utf-8')
@@ -400,6 +434,16 @@ class TestUnidiffParser(unittest.TestCase):
 
         self.assertEqual(hunk_positions, expected_hunk_positions)
 
+    def test_binary_patch(self):
+        utf8_file = os.path.join(self.samples_dir, 'samples/binary.diff')
+        with open(utf8_file, 'r') as diff_file:
+            res = PatchSet(diff_file)
+            self.assertEqual(len(res), 1)
+            patch = res[0]
+            self.assertEqual(patch.source_file, '/dev/null')
+            self.assertEqual(patch.target_file, 'b/1x1.png')
+            self.assertTrue(patch.is_binary_file)
+            self.assertTrue(patch.is_added_file)
 
 class TestVCSSamples(unittest.TestCase):
     """Tests for real examples from VCS."""
